import isEqual from "lodash/isEqual";
import isString from "lodash/isString";
import getStringLabelKey from './getStringLabelKey';

/**
 * Compare whether options are the same. For custom options, compare the
 * `labelKey` values since a unique id is generated each time, causing the
 * comparison to fail.
 */
export default function areEqual(newItem, existingItem, labelKey) {
  var stringLabelKey = getStringLabelKey(labelKey);

  if (newItem && !isString(newItem) && newItem.customOption && existingItem && !isString(existingItem) && existingItem.customOption) {
    return newItem[stringLabelKey] === existingItem[stringLabelKey];
  }

  return isEqual(newItem, existingItem);
}